import React, { PropTypes } from 'react'
import styled from 'styled-components'
import {
  withSpacing,
  withTextAlign,
  withFlex,
  withDisplay,
  withPosition,
  withOverflow,
  withDimensions,
  withRotate,
  withBorders,
  withTruncate,
  withTextStyles,
  withTransform
} from '../enhancers'

const Styles = {}

Styles.clearfix = () => `
  &:before,
  &:after {
    display: table;
    clear: both;
    content: "";
  }
`

Styles.rounded = (val, theme) => {
  const i = Number.isInteger(val) ? val - 1 : 0
  return `
  border-radius: ${theme.borderRadius[i]};
  `
}

Styles.shadow = (val, theme) => {
  const i = Number.isInteger(val) ? val - 1 : 0
  return `
  box-shadow: ${theme.shadows[i]};
  `
}

const getBorderRadius = ({ rounded, circle }, theme) => {
  if (circle) return `border-radius: 9999px;`
  if (rounded) return  Styles.rounded(rounded, theme)
  return ''
}

const styles = ({
  rounded,
  shadow,
  clearfix,
  backgroundColor,
  circle,
  theme
}) => `
  ${clearfix ? Styles.clearfix() : ''}
  ${shadow ? Styles.shadow(shadow, theme) : ''}
  ${getBorderRadius({ rounded, circle }, theme)}
  ${backgroundColor ? `background-color: ${backgroundColor};` : ''}
`

const Box = styled(({
  is = 'div',
  rounded,
  shadow,
  clearfix,
  backgroundColor,
  circle,
  theme,
  ...props
}) => React.createElement(is, props))`${styles}`

Box.propTypes = {
  children: PropTypes.any,
  clearfix: PropTypes.bool,
  is: PropTypes.oneOfType([
    PropTypes.string,
    PropTypes.element
  ]),
  backgroundColor: PropTypes.string,
  rounded: PropTypes.oneOfType([
    PropTypes.bool,
    PropTypes.oneOf([1, 2, 3])
  ]),
  circle: PropTypes.bool,
  shadow: PropTypes.oneOfType([
    PropTypes.bool,
    PropTypes.oneOf([1, 2])
  ])
}

Box.displayName = 'Box'

// Decorate Box with higher order components
export default [
  withSpacing,
  withTextAlign,
  withTextStyles,
  withFlex,
  withDisplay,
  withPosition,
  withOverflow,
  withDimensions,
  withRotate,
  withTransform,
  withBorders,
  withTruncate
].reduce((comp, hoc) => hoc(comp), Box)
