import React from 'react'
import { storiesOf, action, linkTo } from '@kadira/storybook'
import {
  App,
  Pane,
  Text,
  NavigationBar,
  NavigationBarLink,
  SubNavigationBar,
  SubNavigationBarLink,
  Sidebar,
  SidebarLink,
  Avatar,
  Box,
  Link,
  Triangle,
  Input,
  Button
} from '../components'

const Label = (props) => <Text is='label' textStyle='display4' bold block {...props}/>

const AvatarWithTriangle = () => <Box display='inline-flex' alignItems='center'>
  <Avatar marginLeft={2} marginRight={2} src='' imageSize='small'>Segment Sloth</Avatar>
  <Triangle aim='down'  display='inline-flex' fill='white' />
</Box>

export default function layoutsStory (module) {
  storiesOf('Layouts', module)
    .add('tabbed Nav + Sub Nav', () => (
      <App>
        <NavigationBar left={'Sloth Corp Media'} right={<AvatarWithTriangle />}>
          <NavigationBarLink active>Sources</NavigationBarLink>
          <NavigationBarLink href='#'>Warehouses</NavigationBarLink>
        </NavigationBar>
        <SubNavigationBar left={'Sources'}>
          {['Overview', 'Integrations', 'Debugger', 'Schema', 'Settings'].map(name =>
            <SubNavigationBarLink href='#' active={name === 'Settings'}>
              {name}
            </SubNavigationBarLink>
          )}
        </SubNavigationBar>
        <Pane flexAuto display='flex'>
          <Sidebar>
            <SidebarLink href='#' active>Basic</SidebarLink>
            <SidebarLink href='#'>Collaborators</SidebarLink>
            <SidebarLink href='#'>SQL Settings</SidebarLink>
            <SidebarLink href='#'>Clear Schema</SidebarLink>
            <SidebarLink href='#'>Transfer To Workspace</SidebarLink>
            <SidebarLink href='#'>API Keys</SidebarLink>
          </Sidebar>
          <Pane display='flex' flexAuto justifyContent='center'>
            <Pane width='680px' margin={8}>
              <Pane white rounded border padding={8}>
                <Text is='h2' display marginBottom={6}>Basic Settings</Text>
                <Label htmlFor='Nickname'>Nickname</Label>
                <Input id='Nickname' value='Slothzilla' name='Nickname' marginTop={2} marginBottom={2} />
                <Text textStyle='body2'>Pick a name to help you identify this source in Segment.</Text>
                <Button primary marginTop={6}>Save changes</Button>
                <Pane white borderTop textStyle='body2' marginTop={6} paddingTop={6}>
                  <Link underline primary href=''>Delete this source.</Link> No data will be deleted from your source.
                </Pane>
              </Pane>
            </Pane>
          </Pane>
        </Pane>
      </App>
    ))
}
